# Features

* Minimalistic fully typed package
* Importable locations: files and named modules
* Handy helper utils
* Configurable resolution when module is already imported: `reuse`, `reload`, `replace`, `rename`, `raise`
* Atomic import: on `ImportError`, old module with the same name will be restored, and partially initialized module will be removed
